@@ -4,17 +4,23 @@ from typing import Any, Dict, List, Optional, Set, Tuple
 import numpy as np
 import pandas as pd
 import pyarrow as pa
+
 from triad.collections.dict import IndexedOrderedDict
 from triad.utils.assertion import assert_arg_not_none, assert_or_throw
+from triad.utils.pandas_like import PD_UTILS
 from triad.utils.pyarrow import (
     expression_to_schema,
     is_supported,
     schema_to_expression,
     to_pa_datatype,
     to_pandas_dtype,
-    validate_column_name,
 )
-from triad.utils.pandas_like import PD_UTILS
+from triad.utils.schema import (
+    quote_name,
+    safe_replace_out_of_quote,
+    safe_search_out_of_quote,
+    safe_split_and_unquote,
+)
 
 
 class SchemaError(Exception):
@@ -46,9 +52,6 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
     * pyarrow.Field: will only use the type attribute of the field
     * type expression or other objects: for :func:`~triad.utils.pyarrow.to_pa_datatype`
 
-    The column name must follow the rules
-    by :func:`~triad.utils.pyarrow.validate_column_name`
-
     .. admonition:: Examples
 
         .. code-block:: python
@@ -180,8 +183,6 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
         self, name: str, value: Any, *args: List[Any], **kwds: Dict[str, Any]
     ) -> None:
         assert_arg_not_none(value, "value")
-        if not validate_column_name(name):
-            raise SchemaError(f"Invalid column name {name}")
         if name in self:  # update existing value is not allowed
             raise SchemaError(f"{name} already exists in {self}")
         if isinstance(value, pa.Field):
@@ -306,13 +307,13 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
             )
         od = OrderedDict(target)
         for k, v in pairs:
-            k = k.strip()
-            if k == "":
-                continue
+            # k = k.strip()
+            # if k == "":
+            #    continue
             if k not in od:
                 if ignore_key_mismatch:
                     continue
-                raise SchemaError(f"Can't remove {k} from {target}")
+                raise SchemaError(f"Can't remove {quote_name(k)} from {target}")
             if v is None:
                 del od[k]
             else:
@@ -368,9 +369,6 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
             )
         fields = []
         for k, v in pairs:
-            k = k.strip()
-            if k == "":
-                continue
             if k not in self:
                 if ignore_key_mismatch:
                     continue
@@ -486,15 +484,17 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
                 if callable(a):
                     result += a(self)
                 elif isinstance(a, str):
-                    op_pos = [i for i, c in enumerate(a) if c in ["-", "~", "+"]]
+                    op_pos = [x[0] for x in safe_search_out_of_quote(a, "-~+")]
                     op_pos.append(len(a))
-                    s = Schema(a[: op_pos[0]].replace("*", str(self)))
+                    s = Schema(
+                        safe_replace_out_of_quote(a[: op_pos[0]], "*", str(self))
+                    )
                     for i in range(0, len(op_pos) - 1):
                         op, expr = a[op_pos[i]], a[(op_pos[i] + 1) : op_pos[i + 1]]
                         if op in ["-", "~"]:
-                            cols = [
-                                x.strip() for x in expr.split(",") if x.strip() != ""
-                            ]
+                            cols = safe_split_and_unquote(
+                                expr, ",", on_unquoted_empty="ignore"
+                            )
                             s = s.exclude(cols) if op == "~" else s - cols
                         else:  # +
                             overwrite = Schema(expr)
@@ -522,9 +522,6 @@ class Schema(IndexedOrderedDict[str, pa.Field]):
         return self
 
     def _validate_field(self, field: pa.Field) -> pa.Field:
-        assert_or_throw(
-            validate_column_name(field.name), SchemaError(f"{field} name is invalid")
-        )
         assert_or_throw(
             is_supported(field.type), SchemaError(f"{field} type is not supported")
         )
