@@ -1,6 +1,7 @@
 import json
 import pickle
 from datetime import date, datetime
+from functools import partial
 from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple
 
 import numpy as np
@@ -243,6 +244,48 @@ def is_supported(data_type: pa.DataType, throw: bool = False) -> bool:
     raise NotImplementedError(f"{data_type} is not supported by Triad")
 
 
+def get_alter_func(
+    from_schema: pa.Schema, to_schema: pa.Schema, safe: bool
+) -> Callable[[pa.Table], pa.Table]:
+    """Generate the alteration function based on ``from_schema`` and
+    ``to_schema``. This function can be applied to arrow tables with
+    ``from_schema``, the outout will be in ``to_schema``'s order and types
+
+    :param from_schema: the source schema
+    :param to_schema: the destination schema
+    :param safe: whether to check for conversion errors such as overflow
+    :return: a function that can be applied to arrow tables with
+        ``from_schema``, the outout will be in ``to_schema``'s order
+        and types
+    """
+    params: List[Tuple[pa.Field, int, bool]] = []
+    same = True
+    for i, f in enumerate(to_schema):
+        j = from_schema.get_field_index(f.name)
+        if j < 0:
+            raise KeyError(f"{f.name} is not in {from_schema}")
+        other = from_schema.field(j)
+        pos_same, type_same = (i == j), (f.type == other.type)
+        same &= pos_same & type_same
+        params.append((f, j, type_same))
+
+    def _alter(df: pa.Table, params: List[Tuple[pa.Field, int, bool]]) -> pa.Table:
+        cols: List[pa.ChunkedArray] = []
+        names: List[str] = []
+        for field, pos, same in params:
+            names.append(field.name)
+            col = df.column(pos)
+            if not same:
+                col = col.cast(field.type, safe=safe)
+            cols.append(col)
+
+        return pa.Table.from_arrays(cols, names=names)
+
+    if same:
+        return lambda x: x
+    return partial(_alter, params=params)
+
+
 def schemas_equal(
     a: pa.Schema, b: pa.Schema, check_order: bool = True, check_metadata: bool = True
 ) -> bool:
